@@ -13,16 +13,17 @@ def keyboard_to_url(
     key_code: int | None = None,
     url: str | None = None,
 ):
-    """Map a keyboard key to open a new tab with a given URL.
+    """
+
+    Map a keyboard key to open a new tab with a given URL.
+
     Args:
         key (str, optional): Key to trigger (example 'k'). Defaults to None.
         key_code (int, optional): If key doesn't work, try hard-coding the key_code instead. Defaults to None.
         url (str, optional): Opens the input URL in new tab. Defaults to None.
     """
 
-    assert not (
-        key and key_code
-    ), """You can not provide key and key_code.
+    assert not (key and key_code), """You can not provide key and key_code.
     Either give key and we'll try to find its associated key_code. Or directly
     provide the key_code."""
 
@@ -73,10 +74,9 @@ def example():
 
 __title__ = "Keyboard to URL"
 __desc__ = (
-    "Create bindings so that hitting a key on your keyboard opens an URL in a"
-    " new tab!"
+    "Create bindings so that hitting a key on your keyboard opens an URL in a new tab!"
 )
 __icon__ = "🎯"
 __examples__ = [example]
 __author__ = "Arnaud Miribel"
-__author__ = "Arnaud Miribel"
+__playground__ = True
