@@ -9,6 +9,7 @@ from .. import extra
 def stoggle(summary: str, content: str):
     """
     Displays a toggle widget in Streamlit
+
     Args:
         summary (str): Summary of the toggle (always shown)
         content (str): Content shown after toggling
@@ -40,4 +41,4 @@ __examples__ = [example]
 __author__ = "Arnaud Miribel"
 __github_repo__ = "arnaudmiribel/stoggle"
 __streamlit_cloud_url__ = "http://stoggle.streamlitapp.com"
-__experimental_playground__ = True
+__playground__ = True
