@@ -20,9 +20,8 @@ def example():
 
 
 __title__ = "Toggle Switch"  # title of your extra!
-__desc__ = (
-    "On/Off Toggle Switch with color customizations"  # description of your extra!
-)
+__desc__ = """On/Off Toggle Switch with color customizations.
+    **Note:** [st.toggle](https://docs.streamlit.io/library/api-reference/widgets/st.toggle) has been released in Streamlit 1.26.0!"""
 __icon__ = "🔛"  # give your extra an icon!
 __examples__ = [example]  # create some examples to show how cool your extra is!
 __author__ = "Carlos D. Serrano"
@@ -30,4 +29,5 @@ __pypi_name__ = "streamlit-toggle-switch"
 __package_name__ = "streamlit_toggle"
 __github_repo__ = "sqlinsights/streamlit-toggle-switch"  # Optional
 __forum_url__ = "https://discuss.streamlit.io/t/streamlit-toggle-switch/32474"
-__experimental_playground__ = False  # Optional
+__playground__ = True
+__deprecated__ = True
